@@ -10,12 +10,12 @@ class Footprint:
         self.mem_size = mem_size
 
     def __eq__(self, other):
+        if self.cpu_hardware != other.cpu_hardware:
+            return False
         if self.cpu_count and other.cpu_count and self.cpu_count != other.cpu_count:
             return False
         if self.mem_size and other.mem_size and self.mem_size != other.mem_size:
             return False
-        if self.cpu_hardware and other.cpu_hardware and self.cpu_hardware != other.cpu_hardware:
-            return False
 
         return True
 
