@@ -1,12 +1,14 @@
 from syncloud.tools.footprint import Footprint
 from syncloud.tools.id import getname
 
+
 def test_getname_cubietruck():
-    f = Footprint('Cubian', cpu_count=2, mem_size=1911201792)
+    f = Footprint('sun7i', cpu_count=2, mem_size=1911201792)
     name = getname(f)
     assert name == 'cubietruck'
 
+
 def test_getname_unknown():
-    f = Footprint('Linux', cpu_count=16, mem_size=2000000000)
+    f = Footprint('i386', cpu_count=16, mem_size=2000000000)
     name = getname(f)
     assert name is None
\ No newline at end of file
